@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2018-2021 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2018-2023 <tsujan2000@gmail.com>
  *
  * Arqiver is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -38,6 +38,9 @@
 
 namespace Arqiver {
 
+static const QRegularExpression newlineExp("(?<!\\\\)\\\\n");
+static const QRegularExpression tabExp("(?<!\\\\)\\\\t");
+
 Backend::Backend(QObject *parent) : QObject(parent) {
   tarCmnd_ = TAR_CMD;
   proc_.setProcessChannelMode(QProcess::MergedChannels);
@@ -131,7 +134,8 @@ void Backend::loadFile(const QString& path, bool withPassword) {
            || mt == "application/x-xz"
            || mt == "application/zstd"
            || mt == "application/x-ace"
-           || mt == "application/x-bzip" || mt == "application/x-bzpdf" || mt == "application/x-xzpdf") {
+           || mt == "application/x-bzip" || mt == "application/x-bzpdf" || mt == "application/x-xzpdf"
+           || mt == "application/x-apple-diskimage") {
     is7z_ = true; isGzip_ = false;
   }
   else if (mt == "application/x-raw-disk-image") {
@@ -314,7 +318,13 @@ void Backend::startAdd(const QStringList& paths,  bool absolutePaths) {
     }
   }
   args << "-c" << "-a";
-  args << fileArgs_;
+  bool fileExists(QFile::exists(filepath_));
+  if (fileExists) { // use a temporary file to append to the existing archive
+    skipExistingFiles(tmpfilepath_); // practically not required
+    args << "-f" << tmpfilepath_;
+  }
+  else
+    args << fileArgs_;
   /* now, setup the parent dir */
   if (!absolutePaths) {
     for (int i = 0; i < filePaths.length(); i++) {
@@ -327,11 +337,8 @@ void Backend::startAdd(const QStringList& paths,  bool absolutePaths) {
   else
     args << "-C" << "/";
   args << filePaths;
-  if (QFile::exists(filepath_)) { // append to the existing archive
-    skipExistingFiles(tmpfilepath_); // practically not required
-    args.replaceInStrings(filepath_, tmpfilepath_);
+  if (fileExists) // append to the existing archive
     args << "@" + filepath_;
-  }
   keyArgs_ << "-c" << "-a" << "-C";
   proc_.start(tarCmnd_, args);
 }
@@ -356,9 +363,8 @@ void Backend::startRemove(const QStringList& paths) {
     return;
   }
   args << "-c" << "-a";
-  args << fileArgs_;
   skipExistingFiles(tmpfilepath_); // practically not required
-  args.replaceInStrings(filepath_, tmpfilepath_);
+  args << "-f" << tmpfilepath_;
   for (int i = 0; i < filePaths.length(); i++) {
     args << "--exclude" << escapedWildCard(filePaths.at(i));
   }
@@ -409,8 +415,7 @@ void Backend::startExtract(const QString& path, const QStringList& files, bool o
   if (!filesList.isEmpty()) {
     filesList.removeDuplicates();
     /* the paths may contain newlines, which have been escaped and are restored here */
-    filesList.replaceInStrings(QRegularExpression("(?<!\\\\)\\\\n"), "\n")
-             .replaceInStrings(QRegularExpression("(?<!\\\\)\\\\t"), "\t");
+    filesList.replaceInStrings(newlineExp, "\n").replaceInStrings(tabExp, "\t");
   }
 
   if (is7z_) {
@@ -456,8 +461,7 @@ void Backend::startExtract(const QString& path, const QStringList& files, bool o
     if (!archiveSingleRoot.isEmpty() && archiveSingleRoot.startsWith("."))
       archiveSingleRoot.remove(0, 1); // no hidden extraction folder
     if (!archiveSingleRoot.isEmpty()) { // is empty with some rpm archives or when an encrypted list isn't known yet
-      archiveSingleRoot.replace(QRegularExpression("(?<!\\\\)\\\\n"), "\n")
-                       .replace(QRegularExpression("(?<!\\\\)\\\\t"), "\t");
+      archiveSingleRoot.replace(newlineExp, "\n").replace(tabExp, "\t");
       if (QFile::exists(xPath + "/" + archiveSingleRoot)) {
         archiveRootExists = true;
         QDir dir (xPath);
@@ -584,8 +588,7 @@ void Backend::removeSingleExtracted(const QString& archivePath) const {
 bool Backend::startViewFile(const QString& path) {
   /* the path may contain newlines, which have been escaped and are restored here */
   QString realPath(path);
-  realPath.replace(QRegularExpression("(?<!\\\\)\\\\n"), "\n")
-          .replace(QRegularExpression("(?<!\\\\)\\\\t"), "\t");
+  realPath.replace(newlineExp, "\n").replace(tabExp, "\t");
 
   QString parentDir = arqiverDir_;
   if (!arqiverDir_.isEmpty()) {
@@ -677,8 +680,7 @@ void Backend::extractTempFiles(const QStringList& paths) {
   realPaths.removeAll(QString());
   if (!realPaths.isEmpty()) {
     realPaths.removeDuplicates();
-    realPaths.replaceInStrings(QRegularExpression("(?<!\\\\)\\\\n"), "\n")
-             .replaceInStrings(QRegularExpression("(?<!\\\\)\\\\t"), "\t");
+    realPaths.replaceInStrings(newlineExp, "\n").replaceInStrings(tabExp, "\t");
   }
   else { // should never happen in practice
     emit processFinished(true, QString());
@@ -1192,7 +1194,7 @@ void Backend::processData() {
   if (is7z_ && !encryptionQueried_) {
     if (!encryptedList_) {
       QString read = proc_.readAllStandardOutput();
-      if (read.contains("\nERROR: ")) { // ERROR: FILE_PATH : Can not open encrypted archive. Wrong password?
+      if (read.contains("\nERROR: ") && read.contains("encrypted")) { // ERROR: FILE_PATH : Can not open encrypted archive. Wrong password?
         encryptedList_ = encrypted_ = true;
       }
       else {
