@@ -4,7 +4,7 @@
 <context>
     <name>Arqiver::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="128"/>
+        <location filename="../../about.ui" line="144"/>
         <source>License</source>
         <translation>Лицензия</translation>
     </message>
@@ -12,44 +12,44 @@
 <context>
     <name>Arqiver::Backend</name>
     <message>
-        <location filename="../../backends.cpp" line="631"/>
-        <location filename="../../backends.cpp" line="664"/>
+        <location filename="../../backends.cpp" line="634"/>
+        <location filename="../../backends.cpp" line="667"/>
         <source>This file is a link but its target does not exist.</source>
         <translation>Этот файл является ссылкой, но целевой файл не существует.</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1047"/>
-        <location filename="../../backends.cpp" line="1078"/>
-        <location filename="../../backends.cpp" line="1121"/>
+        <location filename="../../backends.cpp" line="1049"/>
+        <location filename="../../backends.cpp" line="1080"/>
+        <location filename="../../backends.cpp" line="1123"/>
         <source>Could not read archive</source>
         <translation>Не удалось прочитать архив</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1081"/>
-        <location filename="../../backends.cpp" line="1126"/>
+        <location filename="../../backends.cpp" line="1083"/>
+        <location filename="../../backends.cpp" line="1128"/>
         <source>Archive Loaded</source>
         <translation>Архив загружен</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1088"/>
-        <location filename="../../backends.cpp" line="1174"/>
+        <location filename="../../backends.cpp" line="1090"/>
+        <location filename="../../backends.cpp" line="1176"/>
         <source>Modification Finished</source>
         <translation>Модификация завершена</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1109"/>
-        <location filename="../../backends.cpp" line="1143"/>
+        <location filename="../../backends.cpp" line="1111"/>
+        <location filename="../../backends.cpp" line="1145"/>
         <source>Extraction Finished</source>
         <translation>Распаковка завершена</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1112"/>
-        <location filename="../../backends.cpp" line="1162"/>
+        <location filename="../../backends.cpp" line="1114"/>
+        <location filename="../../backends.cpp" line="1164"/>
         <source>Extraction Failed</source>
         <translation>Ошибка распаковки</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1271"/>
+        <location filename="../../backends.cpp" line="1273"/>
         <source>%1 is missing from your system.
 Please install it for this kind of archive!</source>
         <translation>%1 отсутствует в вашей системе.
@@ -74,33 +74,28 @@ Clear text with the Escape key.</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="45"/>
+        <location filename="../../pref.ui" line="50"/>
         <source>Start with this size:</source>
         <translation>Начать с данного размера:</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="94"/>
+        <location filename="../../pref.ui" line="118"/>
         <source>Show prompt on removing items</source>
         <translation>Показ подсказки по удалению элементов</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="101"/>
-        <source>Fit first column into available width</source>
-        <translation>Подогнать первый столбец к доступной ширине</translation>
-    </message>
-    <message>
-        <location filename="../../pref.ui" line="108"/>
+        <location filename="../../pref.ui" line="125"/>
         <source>If this is unchecked, only the top level directories will be expanded.</source>
         <translation>Если этот флажок не установлен, будут развернуты только каталоги верхнего уровня.</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="111"/>
+        <location filename="../../pref.ui" line="128"/>
         <source>Expand all directories when opening archives</source>
         <translation>Разворачивать все каталоги при открытии архивов</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="118"/>
-        <location filename="../../pref.ui" line="131"/>
+        <location filename="../../pref.ui" line="140"/>
+        <location filename="../../pref.ui" line="153"/>
         <source>Leave empty for the default.
 
 Warning: Arqiver will not work if the
@@ -111,7 +106,7 @@ binary does not belong to libarchive.</source>
 если двоичный файл не принадлежит к архиву.</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="124"/>
+        <location filename="../../pref.ui" line="146"/>
         <source>libarchive binary:</source>
         <translation>двоичный libarchive:</translation>
     </message>
@@ -121,23 +116,23 @@ binary does not belong to libarchive.</source>
         <translation>Запомнить &amp;размер окна при закрытии</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="83"/>
+        <location filename="../../pref.ui" line="93"/>
         <source>Size of view icons:</source>
         <translation>Размер значков просмотра:</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="56"/>
+        <location filename="../../pref.cpp" line="54"/>
         <source>px</source>
         <translation>пикс</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="226"/>
-        <location filename="../../pref.cpp" line="251"/>
+        <location filename="../../pref.cpp" line="208"/>
+        <location filename="../../pref.cpp" line="233"/>
         <source>Application restart is needed for changes to take effect.</source>
         <translation>Для вступления изменений в силу, необходим перезапуск приложения.</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="240"/>
+        <location filename="../../pref.cpp" line="222"/>
         <source>Select libarchive binary</source>
         <translation>Выбрать бинарный libarchive</translation>
     </message>
@@ -170,443 +165,448 @@ binary does not belong to libarchive.</source>
         <translation>&amp;Вид</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="162"/>
+        <location filename="../../mainWin.ui" line="164"/>
         <source>&amp;Help</source>
         <translation>&amp;Справка</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="198"/>
+        <location filename="../../mainWin.ui" line="200"/>
         <source>&amp;Open Archive</source>
         <translation>&amp;Открыть архив</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="201"/>
+        <location filename="../../mainWin.ui" line="203"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="206"/>
+        <location filename="../../mainWin.ui" line="208"/>
         <source>&amp;New Archive</source>
         <translation>&amp;Новый архив</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="209"/>
+        <location filename="../../mainWin.ui" line="211"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="214"/>
+        <location filename="../../mainWin.ui" line="216"/>
         <source>&amp;Quit</source>
         <translation>&amp;Выйти</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="217"/>
+        <location filename="../../mainWin.ui" line="219"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="222"/>
+        <location filename="../../mainWin.ui" line="224"/>
         <source>Add File(s)</source>
         <translation>Добавить файл (-ы)</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="227"/>
+        <location filename="../../mainWin.ui" line="229"/>
         <source>Remove File(s)</source>
         <translation>Удалить файл (-ы)</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="232"/>
+        <location filename="../../mainWin.ui" line="234"/>
         <source>Extract All</source>
         <translation>Распаковать всё</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="235"/>
+        <location filename="../../mainWin.ui" line="237"/>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="240"/>
+        <location filename="../../mainWin.ui" line="242"/>
         <source>Add Directory</source>
         <translation>Добавить каталог</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="245"/>
+        <location filename="../../mainWin.ui" line="247"/>
         <source>Extract Selection</source>
         <translation>Распаковать выбранное</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="250"/>
+        <location filename="../../mainWin.ui" line="252"/>
         <source>Set Password</source>
         <translation>Задать пароль</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="255"/>
+        <location filename="../../mainWin.ui" line="257"/>
         <source>E&amp;xpand</source>
         <translation>&amp;Развернуть</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="258"/>
+        <location filename="../../mainWin.ui" line="260"/>
         <source>Ctrl+Shift+Down</source>
         <translation>Ctrl+Shift+Down</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="263"/>
+        <location filename="../../mainWin.ui" line="265"/>
         <source>Collap&amp;se</source>
         <translation>Сверну&amp;ть</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="266"/>
+        <location filename="../../mainWin.ui" line="268"/>
         <source>Ctrl+Shift+Up</source>
         <translation>Ctrl+Shift+Up</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="271"/>
+        <location filename="../../mainWin.ui" line="273"/>
         <source>&amp;About</source>
         <translation>&amp;О программе</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="276"/>
+        <location filename="../../mainWin.ui" line="278"/>
         <source>&amp;Copy Current Path</source>
         <translation>&amp;Копировать текущий путь</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="281"/>
+        <location filename="../../mainWin.ui" line="283"/>
         <source>&amp;Preferences</source>
         <translation>&amp;Настройки</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="286"/>
+        <location filename="../../mainWin.ui" line="288"/>
         <source>Stop &amp;Process</source>
         <translation>Остановить &amp;процесс</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="289"/>
+        <location filename="../../mainWin.ui" line="291"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="89"/>
+        <location filename="../../mainWin.cpp" line="148"/>
         <source>Root</source>
         <translation>Корень</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="148"/>
+        <location filename="../../mainWin.cpp" line="212"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="205"/>
+        <location filename="../../mainWin.cpp" line="277"/>
         <source>File</source>
         <translation>Файл</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="205"/>
+        <location filename="../../mainWin.cpp" line="277"/>
         <source>MimeType</source>
         <translation>Тип MIME</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="205"/>
+        <location filename="../../mainWin.cpp" line="277"/>
         <source>Size</source>
         <translation>Размер</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="416"/>
-        <location filename="../../mainWin.cpp" line="686"/>
-        <location filename="../../mainWin.cpp" line="727"/>
+        <location filename="../../mainWin.cpp" line="488"/>
+        <location filename="../../mainWin.cpp" line="759"/>
+        <location filename="../../mainWin.cpp" line="802"/>
         <source>Opening Archive...</source>
         <translation>Открытие архива...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="490"/>
-        <source>All Types %1</source>
-        <translation>Все типы %1</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="500"/>
-        <location filename="../../mainWin.cpp" line="524"/>
-        <source>Uncompressed Archive (*.tar)</source>
-        <translation>Архив без сжатия (*.tar)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="501"/>
-        <location filename="../../mainWin.cpp" line="525"/>
-        <source>GZip Compressed Archive (*.tar.gz *.tgz)</source>
-        <translation>Архив с сжатием GZip (*.tar.gz *.tgz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="503"/>
-        <location filename="../../mainWin.cpp" line="527"/>
-        <source>BZip2 Compressed Archive (*.tar.bz2 *.tbz2 *.tbz)</source>
-        <translation>Архив с сжатием BZip2 (*.tar.bz2 *.tbz2 *.tbz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="504"/>
-        <location filename="../../mainWin.cpp" line="533"/>
-        <source>LMZA Compressed Archive (*.tar.lzma *.tlz)</source>
-        <translation>Архив с сжатием LMZA (*.tar.lzma *.tlz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="505"/>
-        <location filename="../../mainWin.cpp" line="530"/>
-        <source>XZ Compressed Archive (*.tar.xz *.txz)</source>
-        <translation>Архив с сжатием XZ (*.tar.xz *.txz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="506"/>
-        <location filename="../../mainWin.cpp" line="534"/>
-        <source>Zstandard Compressed Archive (*.tar.zst *.tzst)</source>
-        <translation>Архив с сжатием Zstandard (*.tar.zst *.tzst)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="507"/>
-        <location filename="../../mainWin.cpp" line="536"/>
-        <source>CPIO Archive (*.cpio)</source>
-        <translation>Архив CPIO (*.cpio)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="509"/>
-        <location filename="../../mainWin.cpp" line="538"/>
-        <source>AR Archive (*.ar)</source>
-        <translation>Архив AR (*.ar)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="511"/>
-        <location filename="../../mainWin.cpp" line="540"/>
-        <source>Zip Archive (*.zip)</source>
-        <translation>Архив Zip (*.zip)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="512"/>
-        <location filename="../../mainWin.cpp" line="542"/>
-        <source>Gzip Archive (*.gz)</source>
-        <translation>Архив Gzip (*.gz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="513"/>
-        <location filename="../../mainWin.cpp" line="541"/>
-        <source>7-Zip Archive (*.7z)</source>
-        <translation>Архив 7-Zip (*.7z)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="528"/>
-        <source>READ-ONLY: BZip2 Archive (*.bz2)</source>
-        <translation>Только для чтения: архив BZip2 (*.bz2)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="529"/>
-        <source>READ-ONLY: BZip2 Compressed PDF Document (*.pdf.bz2)</source>
-        <translation>Только для чтения: PDF документ с сжатием BZip2 (*.pdf.bz2)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="531"/>
-        <source>READ-ONLY: XZ archive (*.xz)</source>
-        <translation>Только для чтения: архив XZ (*.xz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="532"/>
-        <source>READ-ONLY: XZ Compressed PDF Document (*.pdf.xz)</source>
-        <translation>Только для чтения: PDF документ с сжатием XZ (*.pdf.xz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="535"/>
-        <source>READ-ONLY: Zstandard archive (*.zst)</source>
-        <translation>Только для чтения: архив Zstandard (*.zst)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="543"/>
-        <source>Gzip Compressed PDF Document (*.pdf.gz)</source>
-        <translation>PDF документ с сжатием Gzip (*.pdf.gz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="544"/>
-        <source>READ-ONLY: Compressed SVG Image (*.svgz)</source>
-        <translation>Только для чтения: изображение с сжатием SVG (*.svgz)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="545"/>
-        <location filename="../../mainWin.cpp" line="546"/>
-        <source>READ-ONLY: ISO Image (*.iso *.img)</source>
-        <translation>Только для чтения: образ ISO (*.iso *.img)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="547"/>
-        <source>READ-ONLY: XAR Archive (*.xar)</source>
-        <translation>Только для чтения: архив XAR (*.xar)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="548"/>
-        <source>READ-ONLY: Java Archive (*.jar)</source>
-        <translation>Только для чтения: архив Java (*.jar)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="549"/>
-        <source>READ-ONLY: Debian Package (*.deb)</source>
-        <translation>Только для чтения: пакет Debian (*.deb)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="550"/>
-        <location filename="../../mainWin.cpp" line="551"/>
-        <source>READ-ONLY: RedHat Package (*.rpm)</source>
-        <translation>Только для чтения: пакет RedHat (*.rpm)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="552"/>
-        <source>READ-ONLY: MS Windows Executable (*.exe *.com)</source>
-        <translation>Только для чтения: исполняемый файл MS Windows (*.exe *.com)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="553"/>
-        <source>READ-ONLY: MS Windows Installer Package (*.msi)</source>
-        <translation>Только для чтения: установочный пакет MS Windows (*.msi)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="554"/>
-        <source>READ-ONLY: MS Windows Cabinet Archive (*.cab)</source>
-        <translation>Только для чтения: архив MS Windows Cabinet (*.cab)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="555"/>
-        <source>READ-ONLY: ACE archive (*.ace)</source>
-        <translation>Только для чтения: архив ACE (*.ace)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="556"/>
-        <source>READ-ONLY: Android Package (*.apk)</source>
-        <translation>Только для чтения: пакет Android (*.apk)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="557"/>
-        <source>READ-ONLY: RAR Archive (*.rar)</source>
-        <translation>Только для чтения: архив RAR (*.rar)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="558"/>
-        <source>READ-ONLY: AppImage application bundle (*.appimage)</source>
-        <translation>Только для чтения: пакет приложений AppImage (*.appimage)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="567"/>
-        <source>All Known Types %1</source>
-        <translation>Все известные типы %1</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="572"/>
-        <source>Show All Files (*)</source>
-        <translation>Показать все файлы (*)</translation>
-    </message>
-    <message>
-        <location filename="../../mainWin.cpp" line="622"/>
+        <location filename="../../mainWin.cpp" line="695"/>
         <source>Create Archive</source>
         <translation>Создать архив</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="648"/>
-        <location filename="../../mainWin.cpp" line="836"/>
-        <location filename="../../mainWin.cpp" line="1110"/>
+        <location filename="../../mainWin.cpp" line="721"/>
+        <location filename="../../mainWin.cpp" line="911"/>
+        <location filename="../../mainWin.cpp" line="1196"/>
         <source>Question</source>
         <translation>Вопрос</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="649"/>
+        <location filename="../../mainWin.cpp" line="722"/>
         <source>The following archive already exists:</source>
         <translation>Следующий архив уже существует:</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="651"/>
+        <location filename="../../mainWin.cpp" line="724"/>
         <source>Do you want to replace it?
 </source>
         <translation>Вы хотите заменить это?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="678"/>
+        <location filename="../../mainWin.cpp" line="751"/>
         <source>Open Archive</source>
         <translation>Открытие архива</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="742"/>
-        <location filename="../../mainWin.cpp" line="749"/>
-        <location filename="../../mainWin.cpp" line="785"/>
+        <location filename="../../mainWin.cpp" line="817"/>
+        <location filename="../../mainWin.cpp" line="824"/>
+        <location filename="../../mainWin.cpp" line="860"/>
         <source>Add to Archive</source>
         <translation>Добавить в архив</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="780"/>
-        <location filename="../../mainWin.cpp" line="811"/>
-        <location filename="../../mainWin.cpp" line="1065"/>
-        <location filename="../../mainWin.cpp" line="1071"/>
+        <location filename="../../mainWin.cpp" line="855"/>
+        <location filename="../../mainWin.cpp" line="886"/>
+        <location filename="../../mainWin.cpp" line="1151"/>
+        <location filename="../../mainWin.cpp" line="1157"/>
         <source>Adding Items...</source>
         <translation>Добавление элементов...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="837"/>
+        <location filename="../../mainWin.cpp" line="912"/>
         <source>Do you want to remove the selected item(s)?
 </source>
         <translation>Вы хотите удалить выбранные элементы?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="854"/>
+        <location filename="../../mainWin.cpp" line="929"/>
         <source>Removing Items...</source>
         <translation>Удаление элементов...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1028"/>
-        <location filename="../../mainWin.cpp" line="1043"/>
-        <location filename="../../mainWin.cpp" line="1123"/>
-        <location filename="../../mainWin.cpp" line="1137"/>
+        <location filename="../../mainWin.cpp" line="1114"/>
+        <location filename="../../mainWin.cpp" line="1129"/>
+        <location filename="../../mainWin.cpp" line="1209"/>
+        <location filename="../../mainWin.cpp" line="1223"/>
         <source>Extracting...</source>
         <translation>Распаковка...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="894"/>
+        <location filename="../../mainWin.cpp" line="969"/>
         <source>Copy Archive Path</source>
         <translation>Скопировать путь к архиву</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="899"/>
+        <location filename="../../mainWin.cpp" line="562"/>
+        <source>All Types</source>
+        <translation>Все типы</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="572"/>
+        <location filename="../../mainWin.cpp" line="596"/>
+        <source>Uncompressed Archive</source>
+        <translation>Архив без сжатия</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="573"/>
+        <location filename="../../mainWin.cpp" line="597"/>
+        <source>GZip Compressed Archive</source>
+        <translation>Архив с сжатием GZip</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="575"/>
+        <location filename="../../mainWin.cpp" line="599"/>
+        <source>BZip2 Compressed Archive</source>
+        <translation>Архив с сжатием BZip2</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="576"/>
+        <location filename="../../mainWin.cpp" line="605"/>
+        <source>LMZA Compressed Archive</source>
+        <translation>Архив с сжатием LMZA</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="577"/>
+        <location filename="../../mainWin.cpp" line="602"/>
+        <source>XZ Compressed Archive</source>
+        <translation>Архив с сжатием XZ</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="578"/>
+        <location filename="../../mainWin.cpp" line="606"/>
+        <source>Zstandard Compressed Archive</source>
+        <translation>Архив с сжатием Zstandard</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="579"/>
+        <location filename="../../mainWin.cpp" line="608"/>
+        <source>CPIO Archive</source>
+        <translation>Архив CPIO</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="581"/>
+        <location filename="../../mainWin.cpp" line="610"/>
+        <source>AR Archive</source>
+        <translation>Архив AR</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="583"/>
+        <location filename="../../mainWin.cpp" line="612"/>
+        <source>Zip Archive</source>
+        <translation>Архив Zip</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="584"/>
+        <location filename="../../mainWin.cpp" line="614"/>
+        <source>Gzip Archive</source>
+        <translation>Архив Gzip</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="585"/>
+        <location filename="../../mainWin.cpp" line="613"/>
+        <source>7-Zip Archive</source>
+        <translation>Архив 7-Zip</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="600"/>
+        <source>READ-ONLY: BZip2 Archive</source>
+        <translation>Только для чтения: архив BZip2</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="601"/>
+        <source>READ-ONLY: BZip2 Compressed PDF Document</source>
+        <translation>Только для чтения: PDF документ с сжатием BZip2</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="603"/>
+        <source>READ-ONLY: XZ archive</source>
+        <translation>Только для чтения: архив XZ</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="604"/>
+        <source>READ-ONLY: XZ Compressed PDF Document</source>
+        <translation>Только для чтения: PDF документ с сжатием XZ</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="607"/>
+        <source>READ-ONLY: Zstandard archive</source>
+        <translation>Только для чтения: архив Zstandard</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="615"/>
+        <source>Gzip Compressed PDF Document</source>
+        <translation>PDF документ с сжатием Gzip</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="616"/>
+        <source>READ-ONLY: Compressed SVG Image</source>
+        <translation>Только для чтения: изображение со сжатием SVG</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="617"/>
+        <location filename="../../mainWin.cpp" line="618"/>
+        <source>READ-ONLY: ISO Image</source>
+        <translation>Только для чтения: образ ISO</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="619"/>
+        <source>READ-ONLY: XAR Archive</source>
+        <translation>Только для чтения: архив XAR</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="620"/>
+        <source>READ-ONLY: Java Archive</source>
+        <translation>Только для чтения: архив Java</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="621"/>
+        <source>READ-ONLY: Debian Package</source>
+        <translation>Только для чтения: пакет Debian</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="622"/>
+        <location filename="../../mainWin.cpp" line="623"/>
+        <source>READ-ONLY: RedHat Package</source>
+        <translation>Только для чтения: пакет RedHat</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="624"/>
+        <source>READ-ONLY: MS Windows Executable</source>
+        <translation>Только для чтения: исполняемый файл MS Windows</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="625"/>
+        <source>READ-ONLY: MS Windows Installer Package</source>
+        <translation>Только для чтения: установочный пакет MS Windows</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="626"/>
+        <source>READ-ONLY: MS Windows Cabinet Archive</source>
+        <translation>Только для чтения: архив MS Windows Cabinet</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="627"/>
+        <source>READ-ONLY: ACE archive</source>
+        <translation>Только для чтения: архив ACE</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="628"/>
+        <source>READ-ONLY: Android Package</source>
+        <translation>Только для чтения: пакет Android</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="629"/>
+        <source>READ-ONLY: RAR Archive</source>
+        <translation>Только для чтения: архив RAR</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="630"/>
+        <source>READ-ONLY: AppImage application bundle</source>
+        <translation>Только для чтения: пакет приложений AppImage</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="631"/>
+        <source>READ-ONLY: VirtualBox Extension Pack</source>
+        <translation>Только для чтения: набор расширений VirtualBox</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="640"/>
+        <source>All Known Types</source>
+        <translation>Все известные типы</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="645"/>
+        <source>Show All Files</source>
+        <translation>Показать все файлы</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="975"/>
         <source>Open Containing Folder</source>
         <translation>Открыть папку с архивом</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="917"/>
+        <location filename="../../mainWin.ui" line="296"/>
         <source>View Current Item</source>
         <translation>Просмотр текущего элемента</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="932"/>
-        <location filename="../../mainWin.cpp" line="940"/>
+        <location filename="../../mainWin.cpp" line="1018"/>
+        <location filename="../../mainWin.cpp" line="1026"/>
         <source>Enter Password</source>
         <translation>Введите пароль</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="944"/>
+        <location filename="../../mainWin.cpp" line="1030"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="945"/>
+        <location filename="../../mainWin.cpp" line="1031"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="949"/>
+        <location filename="../../mainWin.cpp" line="1035"/>
         <source>Encrypt the file list</source>
         <translation>Зашифровать список файлов</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="950"/>
+        <location filename="../../mainWin.cpp" line="1036"/>
         <source>This will take effect after files/folders are added.</source>
         <translation>Вступит в силу после добавления файлов/папок.</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1021"/>
-        <location filename="../../mainWin.cpp" line="1097"/>
+        <location filename="../../mainWin.cpp" line="1107"/>
+        <location filename="../../mainWin.cpp" line="1183"/>
         <source>Extract Into Directory</source>
         <translation>Распаковать в каталог</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1111"/>
+        <location filename="../../mainWin.cpp" line="1197"/>
         <source>Some files will be overwritten.
 Do you want to continue?
 </source>
@@ -615,38 +615,38 @@ Do you want to continue?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1259"/>
+        <location filename="../../mainWin.cpp" line="1324"/>
         <source>Link To: %1</source>
         <translation>Ссылка на: %1</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1606"/>
+        <location filename="../../mainWin.cpp" line="1672"/>
         <source>A simple Qt archive manager</source>
         <translation>Простой менеджер архивов на Qt</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1607"/>
+        <location filename="../../mainWin.cpp" line="1673"/>
         <source>based on libarchive, gzip and 7z</source>
         <translation>основанный на libarchive, gzip и 7z</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1608"/>
+        <location filename="../../mainWin.cpp" line="1674"/>
         <source>Author</source>
         <translation>Автор</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1609"/>
+        <location filename="../../mainWin.cpp" line="1675"/>
         <source>aka.</source>
         <translation>aka.</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1610"/>
-        <location filename="../../mainWin.cpp" line="1611"/>
+        <location filename="../../mainWin.cpp" line="1676"/>
+        <location filename="../../mainWin.cpp" line="1677"/>
         <source>About Arqiver</source>
         <translation>О Arqiver</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1610"/>
+        <location filename="../../mainWin.cpp" line="1676"/>
         <source>Translators</source>
         <translation>Переводчики</translation>
     </message>
